@@ -1,21 +1,21 @@
 # Version
-from ._version import __version__
+from bip_utils._version import __version__
 # Base58
-from .base58 import (
+from bip_utils.base58 import (
     Base58ChecksumError, Base58Alphabets,
     Base58Decoder, Base58Encoder
 )
 # Bech32
-from .bech32 import (
+from bip_utils.bech32 import (
     Bech32ChecksumError, Bech32FormatError, AtomBech32FormatError, BchBech32FormatError, SegwitBech32FormatError,
     AtomBech32Decoder, AtomBech32Encoder,
     BchBech32Decoder, BchBech32Encoder,
     SegwitBech32Decoder, SegwitBech32Encoder
 )
 # WIF
-from .wif import WifDecoder, WifEncoder
+from bip_utils.wif import WifDecoder, WifEncoder
 # Address computation
-from .addr import (
+from bip_utils.addr import (
     P2PKH, BchP2PKH, P2SH, BchP2SH, P2WPKH,
     AtomAddr,
     EthAddr,
@@ -23,20 +23,20 @@ from .addr import (
     XrpAddr
 )
 # BIP39
-from .bip import (
+from bip_utils.bip import (
     Bip39InvalidFileError, Bip39ChecksumError,
     Bip39WordsNum, Bip39EntropyBitLen,
     Bip39EntropyGenerator, Bip39MnemonicGenerator, Bip39MnemonicValidator, Bip39SeedGenerator
 )
 # BIP32
-from .bip import (
+from bip_utils.bip import (
     Bip32KeyError, Bip32PathError,
     Bip32Utils,
     Bip32PathParser,
     Bip32
 )
 # BIP44/49/84
-from .bip import (
+from bip_utils.bip import (
     Bip44DepthError, Bip44CoinNotAllowedError,
     Bip44Changes, Bip44Coins, Bip44Levels,
     Bip44,
@@ -44,4 +44,4 @@ from .bip import (
     Bip84
 )
 # Coins configuration
-from .conf import *
+from bip_utils.conf import *
